function [feat] = encode_feature(dict, X)
% Encode raw sequence into feature vector
%
%   F = encode_feature(D, X) encodes raw sequence X with the trained dictionary D
%
%   See also train_dict

  N_INSTANCE = size(X,1);

  N_PATCH_SIZE = dict.N_PATCH_SIZE;

  [patchX, patchIdx] = extract_patches(N_PATCH_SIZE, X);

  assert(length(unique(patchIdx)) == N_INSTANCE)

  N_ENCODING_DIM = size(dict.means_mag,1)*2*size(dict.means_mag,2);

  feat = zeros(N_INSTANCE, N_ENCODING_DIM*2);

  t0 = tic;
  for i = [1:N_INSTANCE]
    rr = find(patchIdx==i);
    x = patchX(rr,:);

    patchX1 = transform_vector(x,'abs');

    enc = vl_fisher(patchX1', dict.means_mag, dict.covariances_mag, dict.priors_mag, 'verbose');
    assert(length(enc) == size(dict.means_mag,1)*2*size(dict.means_mag,2))
    assert(length(enc) <= N_ENCODING_DIM)
    feat(i,1:length(enc)) = enc';


    patchX2 = transform_vector(x,'angle');

    enc = vl_fisher(patchX2', dict.means_ang, dict.covariances_ang, dict.priors_ang, 'verbose');
    assert(length(enc) == size(dict.means_ang,1)*2*size(dict.means_ang,2))
    assert(length(enc) <= N_ENCODING_DIM)
    feat(i,(N_ENCODING_DIM+1):(N_ENCODING_DIM+length(enc))) = enc';

  end  % ./ for instance