function [dict] = train_dict(X, N_PATCH_SIZE, N_DICT_SIZE)
% Train dictionary words from training sequences
%
%   D = encode_feature(X, sizePatch, sizeDict) use raw sequences X to train a dictionary D
%
%   See also encode_feature

  assert(exist('vl_gmm')==3, 'Can not find VLFeat library')

  N_INSTANCE = size(X,1);

  [patchX, ~] = extract_patches(N_PATCH_SIZE, X);

  N_PATCHES = size(patchX,1);

  mappedX1 = transform_vector(patchX,'abs');

  numClusters = N_DICT_SIZE;
  [means1, covariances1, priors1] = vl_gmm(mappedX1', numClusters, 'verbose');

  mappedX2 = transform_vector(patchX,'angle');

  numClusters = N_DICT_SIZE;
  [means2, covariances2, priors2] = vl_gmm(mappedX2', numClusters, 'verbose');


  dict.means_mag = means1; dict.means_ang = means2;
  dict.covariances_mag = covariances1; dict.covariances_ang = covariances2;
  dict.priors_mag = priors1; dict.priors_ang = priors2;
  dict.N_PATCH_SIZE = N_PATCH_SIZE;
  dict.N_DICT_SIZE = N_DICT_SIZE;
  dict.N_INSTANCE = N_INSTANCE;
  dict.N_PATCHES = N_PATCHES;